<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Hapus</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished">Tampilan slide</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished">Ekspor</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">Duplikat</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Putar searah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Putar berlawanan jarum jam</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished">Tampilkan di manajer file</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished">Informasi Foto</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="unfinished">Kembalikan</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Tidak dinamai</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Buat</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Album Baru</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Apakah anda yakin menghapus album ini?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Tempat Sampah</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Impor</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Tempat Sampah</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Atau arahkan foto disini</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Impor Semua</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Impor ke:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Impor</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Disk Sistem</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galeri</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk sibuk, tidak dapat mencabut sekarang</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album Baru</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Abaikan</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Timpa</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ekspor</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumen</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Unduhan</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nama:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Simpan ke:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kualitas:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Pilih folder lain</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Nama file tidak boleh kosong</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>sudah ada. Apakah anda ingin menimpanya?</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 Drive</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Disk %1 Kosong</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 Terenkripsi</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Ekspor Foto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Sedang Menghapus...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Sedang memulihkan...</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation>Apakah anda yakin ingin menghapus foto ini dari album?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Informasi Dasar</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Impor</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Tampilan slide</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ganti nama</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ekspor</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Perangkat</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galeri</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album Baru</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan di manajer file</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Tampilan slide</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Duplikat</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Atur sebagai wallpaper</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar searah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar berlawanan jarum jam</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Sebelumnya</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Selanjutnya</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoritkan</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Batal Favorit</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Ganti nama album</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Album “%1” terhapus</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Berhasil menambahkan ke “%1”</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Impor berhasil</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Impor gagal</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Ekspor gagal</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Ekspor berhasil</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Semua Foto</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Timelines</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Keluar mode layarpenuh/slideshow</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tampilan pintasan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Pilih semua</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Perbesar</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Perkecil</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album Baru</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Halaman atas</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Halaman bawah</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Sedang mengimpor...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Hapus</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Lampu</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Ukuran file</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensi</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Tanggal mengambil foto</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Tanggal diubah</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mode exposure</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program exposure</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Waktu exposure</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>bukaan</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Jarak fokus</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>bukaan maks</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mode pengukuran</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>keseimbangan putih</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>kompensasi pencahayaan</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>model kamera</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>model lensa </translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>ruang warna</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Disk Sistem</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Pilih</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Batal Pilih</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Telah diimpor di</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>diimpor di</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Kembalikan</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoritkan</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar berlawanan jarum jam</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar searah jarum jam</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Sedang mengimpor...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Tidak ditemukan hasil</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Tampilan slide</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Hasil Pencarian</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penu</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ekspor</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Batal Favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar searah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar berlawanan jarum jam</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan di manajer file</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Atur sebagai Wallpaper</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Tampilan slide</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Duplikat</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Informasi Foto</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambahkan ke album</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hapus dari album</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Kembalikan</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album Baru</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">hari</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">Informasi Dasar</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">Tanggal diubah</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Tipe</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">Ukuran file</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">Tanggal mengambil foto</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
